test_that("If no packages, shows nothing", {
  expect_null(.efsaToolsAttachMessage(character()))
})

test_that("Runs correctly with an odd number of packages", {
  local_mocked_bindings(.packageVersionStr = function(x) "1.0.0")
  checkmate::expect_character(.efsaToolsAttachMessage(c("a", "b", "c")))
})
