test_that("The parameter must be a data frame", {
  expect_error(
    .activate(dataframe = 1)
  )
})

test_that("Iris gets activated", {
  checkmate::expect_data_frame(
    .activate(dataframe = iris))
})

test_that("The START_DATE column is present", {
  dataframe_ <- .activate(dataframe = iris)
  expect_true(
    any(names(dataframe_) == "START_DATE"))
  expect_true(
    all(!is.null(dataframe_$START_DATE)))
})

test_that("The END_DATE column is present", {
  dataframe_ <- .activate(dataframe = iris)
  expect_true(
    any(names(dataframe_) == "END_DATE"))
  expect_true(
    all(is.na(dataframe_$END_DATE)))
})

test_that("The IS_ACTIVE column is present", {
  dataframe_ <- .activate(dataframe = iris)
  expect_true(
    any(names(dataframe_) == "IS_ACTIVE"))
  expect_true(
    all(dataframe_$IS_ACTIVE == TRUE))
})
