% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/EFSATools-package.R
\docType{package}
\name{EFSATools-package}
\alias{EFSATools}
\alias{EFSATools-package}
\title{EFSATools: EFSA Ensemble of Data Collections Tools}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Provides tools for dataset operations and utilities designed to preserve data history within EFSA's ad hoc data collections. It also imports packages developed by EFSA that provide additional support for data collection activities.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://openefsa.github.io/EFSATools/}
  \item Report bugs at \url{https://github.com/openefsa/EFSATools/issues}
}

}
\author{
\strong{Maintainer}: Luca Belmonte \email{luca.belmonte@efsa.europa.eu} (\href{https://orcid.org/0000-0002-7977-9170}{ORCID})

Authors:
\itemize{
  \item Lorenzo Copelli (\href{https://orcid.org/0009-0002-4305-065X}{ORCID})
}

}
\keyword{internal}
